"use strict";

Object.defineProperty(exports, "__esModule", {
    value: true
});
exports.Changer = undefined;

var _classCallCheck2 = require("babel-runtime/helpers/classCallCheck");

var _classCallCheck3 = _interopRequireDefault(_classCallCheck2);

var _createClass2 = require("babel-runtime/helpers/createClass");

var _createClass3 = _interopRequireDefault(_createClass2);

var _ModeEraser = require("./ModeEraser");

var _ModeFill = require("./ModeFill");

var _ModeStroke = require("./ModeStroke");

var _ModeClip = require("./ModeClip");

var _ModeText = require("./ModeText");

var _ModeHandTool = require("./ModeHandTool");

var _ModeEyedropper = require("./ModeEyedropper");

var _ModeChanging = require("./ModeChanging");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var Changer = exports.Changer = function () {
    function Changer(layers, prop, dispatcher) {
        (0, _classCallCheck3.default)(this, Changer);

        this.updater = layers.updater;
        this.dispatcher = dispatcher;
        this.prop = prop;
        this.viewer = layers.viewer;
        this.layers = layers;
        this.canvas = Changer.EMPTY_CANVAS;
        this.mode = -1;
    }
    /**
     * モードチェンジ中
     */


    (0, _createClass3.default)(Changer, [{
        key: "getMode",
        value: function getMode() {
            return this.mode;
        }
    }, {
        key: "changeMode",
        value: function changeMode(mode) {
            var _this = this;

            this.mode = this.CHANGING;
            this.reservedMode = mode;
            this.canvas = Changer.EMPTY_CANVAS;
            this.dispatcher.changeMode.dispatch(this.mode);
            var currentId = this.layers.currentId;
            switch (mode) {
                case this.ERASER_MODE:
                    return this.updater.beginPath(currentId).then(function (tran) {
                        return _this.doChangeMode(_this.ERASER_MODE, new _ModeEraser.ModeEraser(_this.viewer, tran, _this.prop));
                    });
                case this.FILL_MODE:
                    return this.updater.beginPath(currentId).then(function (tran) {
                        return _this.doChangeMode(_this.FILL_MODE, new _ModeFill.ModeFill(_this.viewer, tran, _this.prop));
                    });
                case this.STROKE_MODE:
                    return this.updater.beginPath(currentId).then(function (tran) {
                        return _this.doChangeMode(_this.STROKE_MODE, new _ModeStroke.ModeStroke(_this.viewer, tran, _this.prop));
                    });
                case this.CLIP_MODE:
                    return this.updater.beginClip(currentId).then(function (tran) {
                        return _this.doChangeMode(_this.CLIP_MODE, new _ModeClip.ModeClip(_this.viewer, tran, _this.prop));
                    });
                case this.TEXT_MODE:
                    return this.updater.beginText(currentId).then(function (tran) {
                        return _this.doChangeMode(_this.TEXT_MODE, new _ModeText.ModeText(_this.viewer, tran, _this.prop));
                    });
                case this.HAND_TOOL_MODE:
                    return this.updater.beginTransform(currentId).then(function (tran) {
                        return _this.doChangeMode(_this.HAND_TOOL_MODE, new _ModeHandTool.ModeHandTool(tran));
                    });
                case this.EYEDROPPER_MODE:
                    return this.layers.getCurrent().then(function (current) {
                        return Promise.resolve(_this.doChangeMode(_this.EYEDROPPER_MODE, new _ModeEyedropper.ModeEyedropper(current, _this.viewer, _this.prop)));
                    });
                default:
                    break;
            }
            return Promise.resolve(null);
        }
    }, {
        key: "isAliveMode",
        value: function isAliveMode(mode) {
            switch (mode) {
                case this.ERASER_MODE:
                case this.FILL_MODE:
                case this.STROKE_MODE:
                case this.CLIP_MODE:
                case this.TEXT_MODE:
                case this.HAND_TOOL_MODE:
                case this.EYEDROPPER_MODE:
                    return true;
                default:
                    return false;
            }
        }
    }, {
        key: "doChangeMode",
        value: function doChangeMode(mode, canvas) {
            if (this.reservedMode !== mode) {
                return null;
            }
            this.mode = mode;
            this.canvas = canvas;
            this.dispatcher.changeMode.dispatch(this.mode);
            return this.canvas;
        }
    }, {
        key: "CHANGING",
        get: function get() {
            return CHANGING;
        }
        /**
         * 消しゴムツールを示す定数
         */

    }, {
        key: "ERASER_MODE",
        get: function get() {
            return ERASER_MODE;
        }
        /**
         * 塗りツールを示す定数
         */

    }, {
        key: "FILL_MODE",
        get: function get() {
            return FILL_MODE;
        }
        /**
         * 線ツールを示す定数
         */

    }, {
        key: "STROKE_MODE",
        get: function get() {
            return STROKE_MODE;
        }
        /**
         * クリップツールを示す定数
         */

    }, {
        key: "CLIP_MODE",
        get: function get() {
            return CLIP_MODE;
        }
        /**
         * テキストツールを示す定数
         */

    }, {
        key: "TEXT_MODE",
        get: function get() {
            return TEXT_MODE;
        }
        /**
         * 変形ツールを示す定数
         */

    }, {
        key: "HAND_TOOL_MODE",
        get: function get() {
            return TRANSFORM_MODE;
        }
        /**
         * スポイトツールを示す定数
         */

    }, {
        key: "EYEDROPPER_MODE",
        get: function get() {
            return EYEDROPPER_MODE;
        }
    }]);
    return Changer;
}();

Changer.EMPTY_CANVAS = new _ModeChanging.ModeChanging();
var ERASER_MODE = 0;
var FILL_MODE = 1;
var STROKE_MODE = 2;
var CLIP_MODE = 3;
var TEXT_MODE = 4;
var TRANSFORM_MODE = 5;
var EYEDROPPER_MODE = 6;
var CHANGING = 7;
//# sourceMappingURL=Changer.js.map
