"use strict";

Object.defineProperty(exports, "__esModule", {
    value: true
});
exports.Editor = undefined;

var _classCallCheck2 = require("babel-runtime/helpers/classCallCheck");

var _classCallCheck3 = _interopRequireDefault(_classCallCheck2);

var _createClass2 = require("babel-runtime/helpers/createClass");

var _createClass3 = _interopRequireDefault(_createClass2);

var _eventemitter = require("eventemitter3");

var emitter = _interopRequireWildcard(_eventemitter);

var _Layers = require("./Layers");

var _Changer = require("./Changer");

var _drawUpdater = require("@s2study/draw-updater");

var _drawUpdater2 = _interopRequireDefault(_drawUpdater);

var _drawViewer = require("@s2study/draw-viewer");

var _drawViewer2 = _interopRequireDefault(_drawViewer);

var _EditorProperties = require("./EditorProperties");

var _EditorEventListeners = require("./EditorEventListeners");

var _EditorEventDispatchers = require("./EditorEventDispatchers");

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) newObj[key] = obj[key]; } } newObj.default = obj; return newObj; } }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var Editor = exports.Editor = function () {
    function Editor(history, renderer, properties) {
        (0, _classCallCheck3.default)(this, Editor);

        // this.listeners = new Set<UpdateListener>();
        this.history = history;
        this.updater = _drawUpdater2.default.createInstance(history);
        this.renderer = renderer;
        this.viewer = _drawViewer2.default.createInstance(history, renderer);
        var emitter3 = new emitter.EventEmitter();
        this._dispatchers = new _EditorEventDispatchers.EditorEventDispatchers(emitter3);
        this.layers = new _Layers.Layers(this.updater, this.viewer, this, this._dispatchers);
        this._properties = new _EditorProperties.EditorProperties(this._dispatchers, properties);
        this._mode = new _Changer.Changer(this.layers, this._properties, this._dispatchers);
        this._listeners = new _EditorEventListeners.EditorEventListeners(emitter3);
    }

    (0, _createClass3.default)(Editor, [{
        key: "stop",
        value: function stop() {
            this.viewer.stop();
        }
    }, {
        key: "start",
        value: function start() {
            this.viewer.start();
        }
    }, {
        key: "getWidth",
        value: function getWidth() {
            return this.renderer.width;
        }
    }, {
        key: "getHeight",
        value: function getHeight() {
            return this.renderer.height;
        }
    }, {
        key: "undo",
        value: function undo() {
            var _this = this;

            var mode = this.mode.getMode();
            return this.updater.undo().then(function () {
                return _this.mode.changeMode(mode);
            });
        }
    }, {
        key: "redo",
        value: function redo() {
            var _this2 = this;

            var mode = this.mode.getMode();
            return this.updater.redo().then(function () {
                return _this2.mode.changeMode(mode);
            });
        }
    }, {
        key: "canUndo",
        value: function canUndo() {
            return this.updater.canUndo();
        }
    }, {
        key: "canRedo",
        value: function canRedo() {
            return this.updater.canRedo();
        }
    }, {
        key: "reRender",
        value: function reRender() {
            this.viewer.refresh();
        }
    }, {
        key: "setupListener",
        value: function setupListener() {
            var _this3 = this;

            this.history.awaitUpdate(function () {
                try {
                    _this3._dispatchers.update.dispatch(null);
                } catch (e) {
                    console.warn(e);
                }
                _this3.setupListener();
            });
        }
    }, {
        key: "createImageURI",
        value: function createImageURI() {
            return Promise.resolve(this.viewer.createImageDataURI());
        }
    }, {
        key: "generateMessage",
        value: function generateMessage() {
            return Promise.resolve(this.history.generateMessage());
        }
    }, {
        key: "properties",
        get: function get() {
            return this._properties;
        }
    }, {
        key: "canvas",
        get: function get() {
            return this._mode.canvas;
        }
    }, {
        key: "mode",
        get: function get() {
            return this._mode;
        }
    }, {
        key: "events",
        get: function get() {
            return this._listeners;
        }
    }, {
        key: "dispatchers",
        get: function get() {
            return this._dispatchers;
        }
    }]);
    return Editor;
}();
//# sourceMappingURL=Editor.js.map
