"use strict";

Object.defineProperty(exports, "__esModule", {
    value: true
});
exports.Layers = undefined;

var _classCallCheck2 = require("babel-runtime/helpers/classCallCheck");

var _classCallCheck3 = _interopRequireDefault(_classCallCheck2);

var _createClass2 = require("babel-runtime/helpers/createClass");

var _createClass3 = _interopRequireDefault(_createClass2);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var Layers = exports.Layers = function () {
    function Layers(updater, viewer, editor, dispatcher) {
        (0, _classCallCheck3.default)(this, Layers);

        this.updater = updater;
        this.viewer = viewer;
        this.editor = editor;
        this.dispatcher = dispatcher;
    }

    (0, _createClass3.default)(Layers, [{
        key: "layerCount",
        value: function layerCount() {
            return Promise.resolve(this.updater.getLayers().length);
        }
    }, {
        key: "setCurrent",
        value: function setCurrent(index) {
            var layers = this.updater.getLayers();
            if (layers == null || layers.length <= index) {
                return Promise.resolve(null);
            }
            var notice = this.noticeChangeCurrent(this.currentId, this.getCurrentIndex());
            this.currentId = layers[index];
            return this.editor.mode.changeMode(this.editor.mode.getMode()).then(notice);
        }
    }, {
        key: "getCurrent",
        value: function getCurrent() {
            return Promise.resolve(this.getCurrentIndex());
        }
    }, {
        key: "show",
        value: function show(index) {
            this.viewer.show([index]);
        }
    }, {
        key: "hide",
        value: function hide(index) {
            this.viewer.hide([index]);
        }
    }, {
        key: "hideAll",
        value: function hideAll() {
            this.viewer.hide();
        }
    }, {
        key: "showAll",
        value: function showAll() {
            this.viewer.show();
        }
    }, {
        key: "remove",
        value: function remove(index) {
            var _this = this;

            var layers = this.updater.getLayers();
            if (layers == null || layers.length <= index) {
                return Promise.reject(null);
            }
            var notice = this.noticeChangeCurrent(this.currentId, this.getCurrentIndex());
            var lastMode = this.editor.mode.getMode();
            return this.updater.removeLayer(layers[index]).then(function () {
                _this.setCurrent(index);
                if (!_this.editor.mode.isAliveMode(lastMode)) {
                    return null;
                }
                return _this.editor.mode.changeMode(lastMode);
            }).then(notice);
        }
    }, {
        key: "addLayer",
        value: function addLayer() {
            var _this2 = this;

            var lastMode = this.editor.mode.getMode();
            var notice = this.noticeChangeCurrent(this.currentId, this.getCurrentIndex());
            return this.updater.addLayer().then(function () {
                if (!_this2.editor.mode.isAliveMode(lastMode)) {
                    return null;
                }
                return _this2.editor.mode.changeMode(lastMode);
            }).then(notice);
        }
    }, {
        key: "moveTo",
        value: function moveTo(index) {
            var _this3 = this;

            var lastMode = this.editor.mode.getMode();
            var notice = this.noticeChangeCurrent(this.currentId, this.getCurrentIndex());
            return this.updater.beginChangeSequence().then(function (tran) {
                tran.toMove(_this3.currentId, index).commit();
                return null;
            }).then(function () {
                if (!_this3.editor.mode.isAliveMode(lastMode)) {
                    return null;
                }
                return _this3.editor.mode.changeMode(lastMode);
            }).then(notice);
        }
    }, {
        key: "getCurrentIndex",
        value: function getCurrentIndex() {
            var _this4 = this;

            return this.updater.getLayers().findIndex(function (layerId) {
                return layerId === _this4.currentId;
            });
        }
        /**
         *
         * @param lastCurrentId
         * @param lastIndex
         * @returns {Promise<number>}
         */

    }, {
        key: "noticeChangeCurrent",
        value: function noticeChangeCurrent(lastCurrentId, lastIndex) {
            var _this5 = this;

            return function () {
                return Promise.resolve(_this5.updater.getLayers().findIndex(function (layerId) {
                    return layerId === _this5.currentId;
                })).then(function (index) {
                    if (lastIndex !== index || lastCurrentId !== _this5.currentId) {
                        _this5.dispatcher.changeCurrentLayer.dispatch(index);
                    }
                    return index;
                });
            };
        }
    }]);
    return Layers;
}();
//# sourceMappingURL=Layers.js.map
